import 'dotenv/config.js';
import type { GenericParent } from 'myst-common';
import type { Jats } from 'jats-xml';
import type { Options } from '../types.js';
type ProcessedReference = {
    cite?: string;
    footnote?: string;
};
/**
 * This takes a jats object and creates a lookup for resolving citations
 *
 * The keys in the lookup are IDs that may be referenced in citations. These
 * include both ref ids and citation ids. The values in the lookup are lists of
 * objects with either doi, bibtex keys, or footnote key. These must be a list
 * as some references hold multiple citations, and these must include footnotes
 * as sometimes footnotes are in the ref list.
 *
 * This function also writes a bibtex file if necessary and appends footnotes
 * to the jats tree.
 */
export declare function processJatsReferences(jats: Jats, opts?: Options): Promise<Record<string, ProcessedReference[]>>;
/**
 * Resolve cite nodes using reference lookup
 *
 * Cite node may be converted to citeGroup or footnoteReference, depending
 * on the content in the reference lookup dictionary
 */
export declare function resolveJatsCitations(tree: GenericParent, refLookup: Record<string, ProcessedReference[]>): Promise<void>;
export {};
//# sourceMappingURL=references.d.ts.map